@@ -138,6 +138,7 @@ class KCALENDARCORE_EXPORT Calendar : public QObject, public CustomProperties, p
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
     Q_PROPERTY(QIcon icon READ icon WRITE setIcon NOTIFY iconChanged)
     Q_PROPERTY(KCalendarCore::AccessMode accessMode READ accessMode WRITE setAccessMode NOTIFY accessModeChanged)
+    Q_PROPERTY(bool isLoading READ isLoading NOTIFY isLoadingChanged)
 
 public:
     /**
@@ -338,33 +339,11 @@ public:
     void setAccessMode(const AccessMode mode);
 
     /**
-      Clears out the current calendar, freeing all used memory etc.
-    */
-    virtual void close() = 0;
-
-    /**
-      Syncs changes in memory to persistent storage.
-
-      @return true if the save was successful; false otherwise.
-              Base implementation returns true.
-    */
-    virtual bool save();
-
-    /**
-      Loads the calendar contents from storage. This requires that the
-      calendar has been previously loaded (initialized).
-
-      @return true if the reload was successful; otherwise false.
-              Base implementation returns true.
-    */
-    virtual bool reload();
-
-    /**
-      Determine if the calendar is currently being saved.
-
-      @return true if the calendar is currently being saved; false otherwise.
-    */
-    virtual bool isSaving() const;
+     * Returns @c true if the calendar is still loading its data and thus
+     * read access will not return complete (or even any) results.
+     * @since 5.96
+     */
+    bool isLoading() const;
 
     /**
       Returns a list of all categories used by Incidences in this Calendar.
@@ -449,135 +428,6 @@ public:
     */
     virtual Incidence::List instances(const Incidence::Ptr &incidence) const;
 
-    // Notebook Specific Methods //
-
-    /**
-      Clears notebook associations from hash-tables for incidences.
-      Called when in-memory content of the calendar is cleared.
-     */
-    virtual void clearNotebookAssociations();
-
-    /**
-      Associate notebook for an incidence.
-
-      @param incidence incidence
-      @param notebook notebook uid
-
-      @return true if the operation was successful; false otherwise.
-     */
-    virtual bool setNotebook(const Incidence::Ptr &incidence, const QString &notebook);
-
-    /**
-      Get incidence's notebook.
-
-      @param incidence incidence
-
-      @return notebook uid
-     */
-    virtual QString notebook(const Incidence::Ptr &incidence) const;
-
-    /**
-      Get incidence's notebook.
-
-      @param uid is a unique identifier string
-
-      @return notebook uid
-     */
-    virtual QString notebook(const QString &uid) const;
-
-    /**
-      List all uids of notebooks currently in the memory.
-
-      @return list of uids of notebooks
-    */
-    virtual QStringList notebooks() const;
-
-    /**
-      Check if calendar knows about the given notebook.
-      This means that it will be saved by one of the attached storages.
-
-      @param notebook notebook uid
-      @return true if calendar has valid notebook
-    */
-    Q_REQUIRED_RESULT bool hasValidNotebook(const QString &notebook) const;
-
-    /**
-      Add notebook information into calendar.
-      Is usually called by storages only.
-
-      @param notebook notebook uid
-      @param isVisible notebook visibility
-      @return true if operation succeeded
-      @see isVisible()
-    */
-    Q_REQUIRED_RESULT bool addNotebook(const QString &notebook, bool isVisible);
-
-    /**
-      Update notebook information in calendar.
-      Is usually called by storages only.
-
-      @param notebook notebook uid
-      @param isVisible notebook visibility
-      @return true if operation succeeded
-      @see isVisible()
-    */
-    Q_REQUIRED_RESULT bool updateNotebook(const QString &notebook, bool isVisible);
-
-    /**
-      Delete notebook information from calendar.
-      Is usually called by storages only.
-
-      @param notebook notebook uid
-      @return true if operation succeeded
-      @see isVisible()
-    */
-    Q_REQUIRED_RESULT bool deleteNotebook(const QString &notebook);
-
-    /**
-      set DefaultNotebook information to calendar.
-
-      @param notebook notebook uid
-      @return true if operation was successful; false otherwise.
-    */
-    Q_REQUIRED_RESULT bool setDefaultNotebook(const QString &notebook);
-
-    /**
-      Get uid of default notebook.
-
-      @return notebook uid
-     */
-    Q_REQUIRED_RESULT QString defaultNotebook() const;
-
-    /**
-      Check if incidence is visible.
-      @param incidence is a pointer to the Incidence to check for visibility.
-      @return true if incidence is visible, false otherwise
-    */
-    Q_REQUIRED_RESULT bool isVisible(const Incidence::Ptr &incidence) const;
-
-    /**
-      Check if notebook is visible.
-      @param notebook notebook uid.
-      @return true if notebook is visible, false otherwise
-    */
-    Q_REQUIRED_RESULT bool isVisible(const QString &notebook) const;
-
-    /**
-      List all notebook incidences in the memory.
-
-      @param notebook is the notebook uid.
-      @return a list of incidences for the notebook.
-    */
-    virtual Incidence::List incidences(const QString &notebook) const;
-
-    /**
-      List all possible duplicate incidences.
-
-      @param incidence is the incidence to check.
-      @return a list of duplicate incidences.
-    */
-    virtual Incidence::List duplicates(const Incidence::Ptr &incidence);
-
     /**
       Returns the Incidence associated with the given unique identifier.
 
@@ -589,17 +439,6 @@ public:
     */
     Incidence::Ptr incidence(const QString &uid, const QDateTime &recurrenceId = {}) const;
 
-    /**
-      Returns the deleted Incidence associated with the given unique identifier.
-
-      @param uid is a unique identifier string.
-      @param recurrenceId is possible recurrenceid of incidence, default is null
-
-      @return a pointer to the Incidence.
-      A null pointer is returned if no such Incidence exists.
-    */
-    Incidence::Ptr deleted(const QString &uid, const QDateTime &recurrenceId = {}) const;
-
     /**
       Delete all incidences that are instances of recurring incidence @p incidence.
 
@@ -697,27 +536,6 @@ public:
     */
     virtual bool deleteEventInstances(const Event::Ptr &event) = 0;
 
-#if KCALENDARCORE_ENABLE_DEPRECATED_SINCE(5, 95)
-    /**
-      Sort a list of Events.
-
-      @param eventList is a pointer to a list of Events.
-      @param sortField specifies the EventSortField.
-      @param sortDirection specifies the SortDirection.
-
-      @return a list of Events sorted as specified.
-
-      @deprecated since 5.95 Use the sortEvents(Event::List &&eventList, EventSortField sortField, SortDirection sortDirection)
-      overload instead. In the common case that you are sorting a list in-place, wrapping the @p eventList
-      argument with std::move will be all that's needed. In the less common case you actually want a copy,
-      create that explicitly first.
-    */
-    KCALENDARCORE_DEPRECATED_VERSION(
-        5,
-        95,
-        "Use sortEvents(Event::List &&eventList, EventSortField sortField, SortDirection sortDirection); see API docs for details.")
-    static Event::List sortEvents(const Event::List &eventList, EventSortField sortField, SortDirection sortDirection);
-#endif
     /**
       Sort a list of Events.
 
@@ -792,22 +610,6 @@ public:
     */
     virtual Event::List rawEvents(EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending) const = 0;
 
-#if KCALENDARCORE_BUILD_DEPRECATED_SINCE(5, 95)
-    /**
-      Returns an unfiltered list of all Events which occur on the given
-      timestamp.
-
-      @param dt request unfiltered Event list for this QDateTime only.
-
-      @return the list of unfiltered Events occurring on the specified
-      timestamp.
-
-      @deprecated since 5.95 use rawEventsForDate(dt.date(), dt.timeZone()) overload instead.
-    */
-    KCALENDARCORE_DEPRECATED_VERSION(5, 95, "Use rawEventsForDate(dt.date(), dt.timeZone()) insead")
-    virtual Event::List rawEventsForDate(const QDateTime &dt) const = 0;
-#endif
-
     /**
       Returns an unfiltered list of all Events occurring within a date range.
 
@@ -852,33 +654,6 @@ public:
     */
     virtual Event::Ptr event(const QString &uid, const QDateTime &recurrenceId = {}) const = 0;
 
-    /**
-      Returns the deleted Event associated with the given unique identifier.
-
-      @param uid is a unique identifier string.
-      @param recurrenceId is possible recurrenceId of event, default is null
-
-      @return a pointer to the deleted Event.
-      A null pointer is returned if no such deleted Event exists, or if deletion tracking
-      is disabled.
-
-      @see deletionTracking()
-    */
-    virtual Event::Ptr deletedEvent(const QString &uid, const QDateTime &recurrenceId = {}) const = 0;
-
-    /**
-      Returns a sorted, unfiltered list of all deleted Events for this Calendar.
-
-      @param sortField specifies the EventSortField.
-      @param sortDirection specifies the SortDirection.
-
-      @return the list of all unfiltered deleted Events sorted as specified. An empty list
-      is returned if deletion tracking is disabled.
-
-      @see deletionTracking()
-    */
-    virtual Event::List deletedEvents(EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending) const = 0;
-
     /**
       Returns a sorted, unfiltered list of all possible instances for this recurring Event.
 
@@ -922,26 +697,6 @@ public:
     */
     virtual bool deleteTodoInstances(const Todo::Ptr &todo) = 0;
 
-#if KCALENDARCORE_ENABLE_DEPRECATED_SINCE(5, 95)
-    /**
-      Sort a list of Todos.
-
-      @param todoList is a pointer to a list of Todos.
-      @param sortField specifies the TodoSortField.
-      @param sortDirection specifies the SortDirection.
-
-      @return a list of Todos sorted as specified.
-
-      @deprecated since 5.95 Use the sortTodos(Todo::List &&todoList, TodoSortField sortField, SortDirection sortDirection)
-      overload instead. In the common case that you are sorting a list in-place, wrapping the @p todoList
-      argument with std::move will be all that's needed. In the less common case you actually want a copy,
-      create that explicitly first.
-    */
-    KCALENDARCORE_DEPRECATED_VERSION(5,
-                                     95,
-                                     "Use sortTodos(Todo::List &&todoList, TodoSortField sortField, SortDirection sortDirection); see API docs for details.")
-    static Todo::List sortTodos(const Todo::List &todoList, TodoSortField sortField, SortDirection sortDirection);
-#endif
     /**
       Sort a list of Todos.
 
@@ -1034,33 +789,6 @@ public:
     */
     virtual Todo::Ptr todo(const QString &uid, const QDateTime &recurrenceId = {}) const = 0;
 
-    /**
-      Returns the deleted Todo associated with the given unique identifier.
-
-      @param uid is a unique identifier string.
-      @param recurrenceId is possible recurrenceId of todo, default is null
-
-      @return a pointer to the deleted Todo.
-      A null pointer is returned if no such deleted Todo exists or if deletion tracking
-      is disabled.
-
-      @see deletionTracking()
-    */
-    virtual Todo::Ptr deletedTodo(const QString &uid, const QDateTime &recurrenceId = {}) const = 0;
-
-    /**
-      Returns a sorted, unfiltered list of all deleted Todos for this Calendar.
-
-      @param sortField specifies the TodoSortField.
-      @param sortDirection specifies the SortDirection.
-
-      @return the list of all unfiltered deleted Todos sorted as specified. An empty list
-      is returned if deletion tracking is disabled.
-
-      @see deletionTracking()
-    */
-    virtual Todo::List deletedTodos(TodoSortField sortField = TodoSortUnsorted, SortDirection sortDirection = SortDirectionAscending) const = 0;
-
     /**
       Returns a sorted, unfiltered list of all possible instances for this recurring Todo.
 
@@ -1105,27 +833,6 @@ public:
     */
     virtual bool deleteJournalInstances(const Journal::Ptr &journal) = 0;
 
-#if KCALENDARCORE_ENABLE_DEPRECATED_SINCE(5, 95)
-    /**
-      Sort a list of Journals.
-
-      @param journalList is a pointer to a list of Journals.
-      @param sortField specifies the JournalSortField.
-      @param sortDirection specifies the SortDirection.
-
-      @return a list of Journals sorted as specified.
-
-      @deprecated since 5.95 Use the sortJournals(Journal::List &&journalList, JournalSortField sortField, SortDirection sortDirection)
-      overload instead. In the common case that you are sorting a list in-place, wrapping the @p journalList
-      argument with std::move will be all that's needed. In the less common case you actually want a copy,
-      create that explicitly first.
-    */
-    KCALENDARCORE_DEPRECATED_VERSION(
-        5,
-        95,
-        "Use sortJournals(Journal::List &&journalList, JournalSortField sortField, SortDirection sortDirection); see API docs for details.")
-    static Journal::List sortJournals(const Journal::List &journalList, JournalSortField sortField, SortDirection sortDirection);
-#endif
     /**
       Sort a list of Journals.
 
@@ -1187,33 +894,6 @@ public:
     */
     virtual Journal::Ptr journal(const QString &uid, const QDateTime &recurrenceId = {}) const = 0;
 
-    /**
-      Returns the deleted Journal associated with the given unique identifier.
-
-      @param uid is a unique identifier string.
-      @param recurrenceId is possible recurrenceId of journal, default is null
-
-      @return a pointer to the deleted Journal.
-      A null pointer is returned if no such deleted Journal exists or if deletion tracking
-      is disabled.
-
-      @see deletionTracking()
-    */
-    virtual Journal::Ptr deletedJournal(const QString &uid, const QDateTime &recurrenceId = {}) const = 0;
-
-    /**
-      Returns a sorted, unfiltered list of all deleted Journals for this Calendar.
-
-      @param sortField specifies the JournalSortField.
-      @param sortDirection specifies the SortDirection.
-
-      @return the list of all unfiltered deleted Journals sorted as specified. An empty list
-      is returned if deletion tracking is disabled.
-
-      @see deletionTracking()
-    */
-    virtual Journal::List deletedJournals(JournalSortField sortField = JournalSortUnsorted, SortDirection sortDirection = SortDirectionAscending) const = 0;
-
     /**
       Returns a sorted, unfiltered list of all instances for this recurring Journal.
 
@@ -1227,37 +907,6 @@ public:
                                            JournalSortField sortField = JournalSortUnsorted,
                                            SortDirection sortDirection = SortDirectionAscending) const = 0;
 
-    // Relations Specific Methods //
-
-    /**
-      Setup Relations for an Incidence.
-      @param incidence is a pointer to the Incidence to have a Relation setup.
-    */
-    virtual void setupRelations(const Incidence::Ptr &incidence);
-
-    /**
-      Removes all Relations from an Incidence.
-
-      @param incidence is a pointer to the Incidence to have a Relation removed.
-    */
-    virtual void removeRelations(const Incidence::Ptr &incidence);
-
-    /**
-      Checks if @p ancestor is an ancestor of @p incidence
-
-      @param ancestor is the incidence we are testing to be an ancestor.
-      @param incidence is the incidence we are testing to be descended from @p ancestor.
-    */
-    bool isAncestorOf(const Incidence::Ptr &ancestor, const Incidence::Ptr &incidence) const;
-
-    /**
-       Returns a list of incidences that have a relation of RELTYPE parent
-       to incidence @p uid.
-
-       @param uid The parent identifier whose children we want to obtain.
-    */
-    Incidence::List relations(const QString &uid) const;
-
     // Filter Specific Methods //
 
     /**
@@ -1465,21 +1114,13 @@ protected:
     void appendRecurringAlarms(Alarm::List &alarms, const Incidence::Ptr &incidence, const QDateTime &from, const QDateTime &to) const;
 
     /**
-      Enables or disabled deletion tracking.
-      Default is true.
-      @see deletedEvent()
-      @see deletedTodo()
-      @see deletedJournal()
-      @since 4.11
+     * Sets the loading state of this calendar.
+     * This is false by default and only needs to be called for calendars
+     * that implement asynchronous loading.
+     * @since 5.96
+     * @see isLoading()
      */
-    void setDeletionTracking(bool enable);
-
-    /**
-      Returns if deletion tracking is enabled.
-      Default is true.
-      @since 4.11
-    */
-    bool deletionTracking() const;
+    void setIsLoading(bool isLoading);
 
     /**
       @copydoc
@@ -1529,6 +1170,13 @@ Q_SIGNALS:
      */
     void ownerChanged();
 
+    /**
+     * Emitted when the loading state changed.
+     * @since 5.96
+     * @see isLoading()
+     */
+    void isLoadingChanged();
+
 private:
     friend class ICalFormat;
 
